Stan Math Library: stan/math/rev/scal/meta/OperandsAndPartials.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
OperandsAndPartials.hpp File Reference
`#include <stan/math/prim/scal/meta/is_constant_struct.hpp>`
`#include <stan/math/prim/scal/meta/length.hpp>`
`#include <stan/math/prim/scal/meta/OperandsAndPartials.hpp>`
`#include <stan/math/prim/scal/meta/VectorView.hpp>`
`#include <stan/math/rev/core.hpp>`

Go to the source code of this file.

## Classes
struct | stan::math::OperandsAndPartials< T1, T2, T3, T4, T5, T6, stan::math::var >
| This class builds partial derivatives with respect to a set of operands. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Variable Documentation

const size_t N_

Definition at line 18 of file OperandsAndPartials.hpp.

vari** operands_

Definition at line 19 of file OperandsAndPartials.hpp.

double* partials_

Definition at line 20 of file OperandsAndPartials.hpp.

[ Stan Home Page ] © 2011–2016, Stan Development Team.